Changelog
=========


1.0a3 (2021-06-29)
------------------

- Add imio.gdpr
  [boulch]

- Add collective.messagesviewlet
  [boulch]

- Add pas.plugins.imio.
  [bsuttor]

- Add collective.bigbang.
  [bsuttor]


1.0a2 (2021-04-22)
------------------

- WEBMIGP5-12: Override TinyMCE Formats inline items
  [laulaz]

- WEBMIGP5-14: Change images behaviors
  [laulaz]

- WEBMIGP5-13: Change files behaviors
  [laulaz]

- Add configuration for TinyMCE toolbars / menus
  [laulaz]

- Add basic demo profile with content creation & improve install profile
  [laulaz]

- Fix navigation links translations
  [laulaz]

- Change header viewlets default order
  [laulaz]

- Migrate & improve buildout for Plone 6
  [boulch]

- Add uninstall profile
  [boulch]

- Fix tests for Plone 6
  [boulch]


1.0a1 (2021-04-19)
------------------

- Initial release.
  [boulch]
